pub struct AutoLinkerStatusResponse {
pub cycles: u64,
pub nodes_processed: u64,
pub edges_created: u64,
pub edges_pruned: u64,
pub edges_deleted: u64,
pub duplicates_found: u64,
pub contradictions_found: u64,
pub last_cycle_duration_ms: u64,
pub cursor: Option<Timestamp>,
pub backlog_size: u64,
}Fields
cycles: u64nodes_processed: u64edges_created: u64edges_pruned: u64edges_deleted: u64duplicates_found: u64contradictions_found: u64last_cycle_duration_ms: u64cursor: Option<Timestamp>backlog_size: u64Trait Implementations
Sourceimpl Clone for AutoLinkerStatusResponse
impl Clone for AutoLinkerStatusResponse
Sourcefn clone(&self) -> AutoLinkerStatusResponse
fn clone(&self) -> AutoLinkerStatusResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AutoLinkerStatusResponse
impl Debug for AutoLinkerStatusResponse
Sourceimpl Default for AutoLinkerStatusResponse
impl Default for AutoLinkerStatusResponse
Sourcefn default() -> AutoLinkerStatusResponse
fn default() -> AutoLinkerStatusResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for AutoLinkerStatusResponse
impl Message for AutoLinkerStatusResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AutoLinkerStatusResponse
impl PartialEq for AutoLinkerStatusResponse
impl Copy for AutoLinkerStatusResponse
impl StructuralPartialEq for AutoLinkerStatusResponse